==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/VpnServerConfigVpnClientRevokedCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRevokedCertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of the revoked VPN client certificate of VpnServerConfiguration.
 * @property name The certificate name.
 * @property thumbprint The revoked VPN client certificate thumbprint.
 */
public data class VpnServerConfigVpnClientRevokedCertificateArgs(
    public val name: Output<String>? = null,
    public val thumbprint: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRevokedCertificateArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRevokedCertificateArgs =
        com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRevokedCertificateArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .thumbprint(thumbprint?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VpnServerConfigVpnClientRevokedCertificateArgs].
 */
@PulumiTagMarker
public class VpnServerConfigVpnClientRevokedCertificateArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var thumbprint: Output<String>? = null

    /**
     * @param value The certificate name.
     */
    @JvmName("ovvtatkfrjxmecwr")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The revoked VPN client certificate thumbprint.
     */
    @JvmName("lakdawjrsafxfoql")
    public suspend fun thumbprint(`value`: Output<String>) {
        this.thumbprint = value
    }

    /**
     * @param value The certificate name.
     */
    @JvmName("vrguogihxxwoygru")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The revoked VPN client certificate thumbprint.
     */
    @JvmName("aaduhpyondjahlpg")
    public suspend fun thumbprint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.thumbprint = mapped
    }

    internal fun build(): VpnServerConfigVpnClientRevokedCertificateArgs =
        VpnServerConfigVpnClientRevokedCertificateArgs(
            name = name,
            thumbprint = thumbprint,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/VpnServerConfigVpnClientRevokedCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRevokedCertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of the revoked VPN client certificate of VpnServerConfiguration.
 * @property name The certificate name.
 * @property thumbprint The revoked VPN client certificate thumbprint.
 */
public data class VpnServerConfigVpnClientRevokedCertificateArgs(
    public val name: Output<String>? = null,
    public val thumbprint: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRevokedCertificateArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRevokedCertificateArgs =
        com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRevokedCertificateArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .thumbprint(thumbprint?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VpnServerConfigVpnClientRevokedCertificateArgs].
 */
@PulumiTagMarker
public class VpnServerConfigVpnClientRevokedCertificateArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var thumbprint: Output<String>? = null

    /**
     * @param value The certificate name.
     */
    @JvmName("lagepxryumqbwpla")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The revoked VPN client certificate thumbprint.
     */
    @JvmName("adsfdkqlxguwqffk")
    public suspend fun thumbprint(`value`: Output<String>) {
        this.thumbprint = value
    }

    /**
     * @param value The certificate name.
     */
    @JvmName("iicqpxcqlntdxvdu")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The revoked VPN client certificate thumbprint.
     */
    @JvmName("eejdibqxsdgvkqey")
    public suspend fun thumbprint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.thumbprint = mapped
    }

    internal fun build(): VpnServerConfigVpnClientRevokedCertificateArgs =
        VpnServerConfigVpnClientRevokedCertificateArgs(
            name = name,
            thumbprint = thumbprint,
        )
}
